==> 0.0.2.tar.gz: lib/models/contracts.dart <==
import 'package:bizdoc/models/models.dart';
import 'notifications.dart';

abstract class ContractBase {
  static ContractBase? construct(String type, Map<String, dynamic> data) {
    switch (type) {
      case 'newMail':
        return NewMail.fromJson(data);
      case 'mailUpdate':
        return MailUpdate.fromJson(data);
      case 'mailDelete':
        return MailDelete.fromJson(data);
      case 'mailHeaderUpdate':
        return MailHeaderUpdate.fromJson(data);
      case 'newNotify':
        return NewNotify.fromJson(data);
      case 'notifyUpdate':
        return NotifyUpdate.fromJson(data);
      case 'commentUpdate':
        return CommentUpdate.fromJson(data);
      case 'commentDelete':
        return CommentDelete.fromJson(data);
      case 'newComment':
        return NewComment.fromJson(data);
      case 'commentTyping':
        return CommentTyping.fromJson(data);
      case 'newChat':
        return NewChat.fromJson(data);
      case 'chatSeen':
        return ChatSeen.fromJson(data);
      case 'chatTyping':
        return ChatTyping.fromJson(data);
      case 'callback':
        return Callback.fromJson(data);
      default:
        print('unexpected hub contract ${data['type']}');
    }
  }
}

abstract class MailContractBase extends ContractBase {}

class NewMail extends MailContractBase {
  final RecipientModel model;
  NewMail(this.model);
  factory NewMail.fromJson(Map<String, dynamic> json) {
    return NewMail(RecipientModel.fromJson(json['model']));
  }
}

class Callback extends ContractBase {
  final dynamic message;

  Callback(this.message);
  Callback.fromJson(Map<String, dynamic> json) : this(json['model']['message']);
}

class MailDelete extends ContractBase {
  final int id;

  MailDelete(this.id);
  MailDelete.fromJson(Map<String, dynamic> json) : this(json['model']['id']);
}

class MailUpdate extends MailContractBase {
  final RecipientModel model;
  final String userId;
  MailUpdate(this.model, this.userId);
  factory MailUpdate.fromJson(Map<String, dynamic> json) {
    return MailUpdate(RecipientModel.fromJson(json['model']), json['userId']);
  }
}

class MailHeaderUpdate extends MailContractBase {
  final HeaderModel model;
  MailHeaderUpdate(this.model);
  factory MailHeaderUpdate.fromJson(Map<String, dynamic> json) {
    return MailHeaderUpdate(HeaderModel.fromJson(json['model']));
  }
}

abstract class NotifyBase extends ContractBase {
  final NotificationBase model;
  NotifyBase(this.model);
}

class NewNotify extends NotifyBase {
  NewNotify(NotificationBase model) : super(model);
  factory NewNotify.fromJson(Map<String, dynamic> json) {
    return NewNotify(NotificationBase.construct(json['model'])!);
  }
}

class NotifyUpdate extends NotifyBase {
  NotifyUpdate(NotificationBase model) : super(model);
  factory NotifyUpdate.fromJson(Map<String, dynamic> json) {
    return NotifyUpdate(NotificationBase.construct(json['model'])!);
  }
}

abstract class CommentContractBase extends MailContractBase {
  /// documentId
  final int id;
  CommentContractBase(this.id);
}

class CommentDelete extends CommentContractBase {
  final int commentId;
  CommentDelete(
    int documentId,
    this.commentId,
  ) : super(documentId);
  factory CommentDelete.fromJson(Map<String, dynamic> json) {
    return CommentDelete(json['id'], json['commentId']);
  }
}

class NewComment extends CommentContractBase {
  final Comment model;
  NewComment(int documentId, this.model) : super(documentId);
  factory NewComment.fromJson(Map<String, dynamic> json) {
    return NewComment(json['id'], Comment.fromJson(json['model']));
  }
}

class CommentUpdate extends CommentContractBase {
  final Comment model;
  CommentUpdate(int documentId, this.model) : super(documentId);
  factory CommentUpdate.fromJson(Map<String, dynamic> json) {
    return CommentUpdate(json['id'], Comment.fromJson(json['model']));
  }
}

abstract class ChatContractBase extends ContractBase {
  abstract final String contactId;
}

class NewChat extends ChatContractBase {
  final Chat model;
  @override
  final String contactId;
  NewChat(this.contactId, this.model);
  factory NewChat.fromJson(Map<String, dynamic> json) {
    return NewChat(json['contactId'], Chat.fromJson(json['model']));
  }
}

class ChatSeen extends ChatContractBase {
  final DateTime time;
  @override
  final String contactId;
  ChatSeen(this.contactId, this.time);
  factory ChatSeen.fromJson(Map<String, dynamic> json) {
    return ChatSeen(json['contactId'], DateTime.parse(json['time']));
  }
}

class ChatTyping extends ChatContractBase {
  @override
  final String contactId;
  ChatTyping(this.contactId);
  factory ChatTyping.fromJson(Map<String, dynamic> json) =>
      ChatTyping(json['contactId']);
}

class CommentTyping extends ContractBase {
  final String userId;
  CommentTyping(this.userId);
  factory CommentTyping.fromJson(Map<String, dynamic> json) =>
      CommentTyping(json['userId']);
}

==> 0.0.3.tar.gz: lib/models/contracts.dart <==
import 'package:bizdoc/models/data.dart';
import 'package:bizdoc/services/session.dart';
import 'chat.dart';
import 'notifications.dart';

abstract class ContractBase {
  static ContractBase? construct(String type, Map<String, dynamic> data) {
    switch (type) {
      case 'newMail':
        return NewMail.fromJson(data);
      case 'mailUpdate':
        return MailUpdate.fromJson(data);
      case 'mailDelete':
        return MailDelete.fromJson(data);
      case 'mailHeaderUpdate':
        return MailHeaderUpdate.fromJson(data);
      case 'newNotify':
        return NewNotify.fromJson(data);
      case 'notifyUpdate':
        return NotifyUpdate.fromJson(data);
      case 'commentUpdate':
        return CommentUpdate.fromJson(data);
      case 'commentDelete':
        return CommentDelete.fromJson(data);
      case 'newComment':
        return NewComment.fromJson(data);
      case 'commentTyping':
        return CommentTyping.fromJson(data);
      case 'newChat':
        return NewChat.fromJson(data);
      case 'chatSeen':
        return ChatSeen.fromJson(data);
      case 'chatTyping':
        return ChatTyping.fromJson(data);
      case 'callback':
        return Callback.fromJson(data);
      default:
        print('unexpected hub contract ${data['type']}');
    }
  }
}

abstract class MailContractBase extends ContractBase {}

class NewMail extends MailContractBase {
  final RecipientModel model;
  NewMail(this.model);
  factory NewMail.fromJson(Map<String, dynamic> json) {
    return NewMail(RecipientModel.fromJson(json['model']));
  }
}

class Callback extends ContractBase {
  final dynamic message;

  Callback(this.message);
  Callback.fromJson(Map<String, dynamic> json) : this(['message']);
}

class MailDelete extends ContractBase {
  final int id;

  MailDelete(this.id);
  MailDelete.fromJson(Map<String, dynamic> json) : this(json['id']);
}

class MailUpdate extends MailContractBase {
  final bool? originalRead;
  final RecipientModel model;
  final String userId;
  MailUpdate(this.model, this.userId, this.originalRead);
  factory MailUpdate.fromJson(Map<String, dynamic> json) {
    return MailUpdate(RecipientModel.fromJson(json['model']), json['userId'],
        json['originalRead']);
  }
}

class MailHeaderUpdate extends MailContractBase {
  final bool? originalRead;
  final HeaderModel model;
  MailHeaderUpdate(this.model, this.originalRead);
  factory MailHeaderUpdate.fromJson(Map<String, dynamic> json) {
    return MailHeaderUpdate(
        HeaderModel.fromJson(json['model']), json['originalRead']);
  }
}

abstract class NotifyBase extends ContractBase {
  final NotificationBase model;
  NotifyBase(this.model);
}

class NewNotify extends NotifyBase {
  NewNotify(NotificationBase model) : super(model);
  factory NewNotify.fromJson(Map<String, dynamic> json) {
    return NewNotify(NotificationBase.construct(json['model'])!);
  }
}

class NotifyUpdate extends NotifyBase {
  final bool? originalRead;
  NotifyUpdate(NotificationBase model, this.originalRead) : super(model);
  factory NotifyUpdate.fromJson(Map<String, dynamic> json) {
    return NotifyUpdate(
        NotificationBase.construct(json['model'])!, json['originalRead']);
  }
}

abstract class CommentContractBase extends MailContractBase {
  /// documentId
  final int id;
  CommentContractBase(this.id);
}

class CommentDelete extends CommentContractBase {
  final int commentId;
  CommentDelete(
    int documentId,
    this.commentId,
  ) : super(documentId);
  factory CommentDelete.fromJson(Map<String, dynamic> json) {
    return CommentDelete(json['id'], json['commentId']);
  }
}

class NewComment extends CommentContractBase {
  final Comment model;
  NewComment(int documentId, this.model) : super(documentId);
  factory NewComment.fromJson(Map<String, dynamic> json) {
    return NewComment(json['id'], Comment.fromJson(json['model']));
  }
}

class CommentUpdate extends CommentContractBase {
  final Comment model;
  CommentUpdate(int documentId, this.model) : super(documentId);
  factory CommentUpdate.fromJson(Map<String, dynamic> json) {
    return CommentUpdate(json['id'], Comment.fromJson(json['model']));
  }
}

abstract class ChatContractBase extends ContractBase {
  abstract final String contactId;
}

class NewChat extends ChatContractBase {
  final Chat model;
  @override
  final String contactId;
  NewChat(this.contactId, this.model);
  factory NewChat.fromJson(Map<String, dynamic> json) {
    return NewChat(json['contactId'], Chat.fromJson(json['model']));
  }
}

class ChatSeen extends ChatContractBase {
  final DateTime time;
  @override
  final String contactId;
  ChatSeen(this.contactId, this.time);
  factory ChatSeen.fromJson(Map<String, dynamic> json) {
    return ChatSeen(json['contactId'], DateTime.parse(json['time']));
  }
}

class ChatTyping extends ChatContractBase {
  @override
  final String contactId;
  ChatTyping(this.contactId);
  factory ChatTyping.fromJson(Map<String, dynamic> json) =>
      ChatTyping(json['contactId']);
}

class CommentTyping extends CommentContractBase {
  final String userId;
  CommentTyping(final int id, this.userId) : super(id);
  factory CommentTyping.fromJson(Map<String, dynamic> json) =>
      CommentTyping(json['id'], json['userId']);
}

class Voted extends CommentContractBase {
  final int commentId;
  final int? votes;
  final int? vote;
  final String userId;

  Voted(int documentId, this.commentId, this.votes, this.vote, this.userId)
      : super(documentId);
  Voted.fromJson(Map<String, dynamic> json)
      : this(
          json['id'],
          json['commentId'],
          json['votes'],
          json['vote'],
          json['userId'],
        );
}

class ProfileChange extends ContractBase {
  final String userId;
  AvailabilityMode mode;
  ProfileChange(this.userId, this.mode);
  ProfileChange.fromJson(Map<String, dynamic> json)
      : this(json['userId'], _parseAvailability(json['mode']));
  static _parseAvailability(String mode) {
    switch (mode) {
      case 'OutOfOffice':
        return AvailabilityMode.outOfOffice;
      case 'Offline':
        return AvailabilityMode.offline;
      case 'Vacation':
        return AvailabilityMode.vacation;
      default:
        return AvailabilityMode.online;
    }
  }
}
